import 'package:flustars/flustars.dart';
import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:get/get.dart';
import 'package:ftrecruiter/api/api_repository.dart';
import 'package:ftrecruiter/comm/utils/log_utils.dart';
import 'package:ftrecruiter/entity/response/industry_data.dart';
import 'package:ftrecruiter/entity/response/server_time.dart';
import 'package:ftrecruiter/entity/response/user_profile.dart';

class DemoController extends GetxController with StateMixin<ServerTime> {
  DemoController({required this.apiRepository});

  final ApiRepository apiRepository;

  final registerEmailController = TextEditingController();

  //调用接口，获取服务器时间
  void getServerTime() {
    //获取服务器时间
    apiRepository.getServerTime(success: (serverTime) {
      Log.d("data:$serverTime");
      change(serverTime, status: RxStatus.success());
    }, onError: (code, msg) {
      Log.d("data-error:$code $msg");
      change(null, status: RxStatus.empty());
    });

    //获取用户信息
    apiRepository.getUserProfile(success: (userProfile) {
      Log.d("user-profile-success - memberId:${userProfile.memberId}");
      SmartDialog.compatible.showToast(
          "get user profile success , memberId:${userProfile.memberId}");
    }, onError: (code, msg) {
      Log.d("user-profile-error:$code $msg");
    });

    //获取行业列表
    apiRepository.getIndustryList(success: (list) {
      Log.d("industry-success list length: ${list.length}");
    }, onError: (code, msg) {
      Log.d("industry-error:$code $msg");
    });
  }

  //测试异步
  void testFuture() async {
    Log.d("start1- ${DateTime.now().millisecondsSinceEpoch}");

    Future.delayed(const Duration(seconds: 3), () {
      Log.d("start3- ${DateTime.now().millisecondsSinceEpoch}");
    });

    Log.d("start2- ${DateTime.now().millisecondsSinceEpoch}");

    String str = await Future.delayed(const Duration(seconds: 2), () {
      return "I Love Flutter";
    });

    Log.d("start5- ${DateTime.now().millisecondsSinceEpoch}");
    Log.d("start4- ${DateTime.now().millisecondsSinceEpoch} $str");

  await Future.delayed(const Duration(seconds: 3));
    Log.d("start6- ${DateTime.now().millisecondsSinceEpoch}");

  }
}
